@@ -1,4 +1,4 @@
-SpatialFiltering <- function (formula, lagformula, data, na.action, nb,
+SpatialFiltering <- function (formula, lagformula=NULL, data=list(), na.action=na.fail, nb=NULL,
  glist=NULL, style="C", zero.policy=NULL, tol=0.1, zerovalue = 0.0001,
  ExactEV=FALSE, symmetric=TRUE, alpha=NULL, alternative="two.sided",
  verbose=NULL) {
@@ -34,6 +34,17 @@ SpatialFiltering <- function (formula, lagformula, data, na.action, nb,
 #
 #  Version 0.9.1 - September 11, 2004
 # Adaptation to formula format Roger Bivand December 2005
+#    .Deprecated("spatialreg::SpatialFiltering", msg="Function SpatialFiltering moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(spatialreg::SpatialFiltering(formula=formula, lagformula=lagformula, data=data, na.action=na.action, nb=nb,
+# glist=glist, style=style, zero.policy=zero.policy, tol=tol, zerovalue = zerovalue,
+# ExactEV=ExactEV, symmetric=symmetric, alpha=alpha, alternative=alternative,
+# verbose=verbose))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     
     if (missing(nb)) stop("Neighbour list argument missing")
     if (missing(formula)) stop("Formula argument missing")
@@ -297,12 +308,30 @@ SpatialFiltering <- function (formula, lagformula, data, na.action, nb,
     class(SFResult) <- "SFResult"
     return(SFResult)
 }
+#}
 
 print.SFResult <- function(x, ...) {
+#    warning("Method print moved to the spatialreg package")
+##    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(print(x=x, ...))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	print(x$selection, ...)
 }
+#}
 
 fitted.SFResult <- function(object, ...) {
+#    warning("Method fitted moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(fitted(object=object, ...))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         if (is.null(object$na.action)) {
 	    res <- object$dataset
         } else {
@@ -323,7 +352,9 @@ fitted.SFResult <- function(object, ...) {
         }
         res
 }
+#}
 
+#if (FALSE) {
 GetMoranStat <- function(MSM, degfree) {
     #MSM    : M %*% S %*% M matrix
     #         M : projection matrix
@@ -338,6 +369,6 @@ GetMoranStat <- function(MSM, degfree) {
     V <- 2 * (degfree * t2 - t1 * t1)/(degfree * degfree * (degfree + 2))
     return(list(Mean=E,Var=V))     
 }
-
+#}
 
 
